@@ -9,17 +9,28 @@ class TestEval(unittest.TestCase):
         result = os.system('tfkit-eval -h')
         self.assertTrue(result == 0)
 
-    def testEvalOnGen(self):
+    def testEvalGen(self):
         result = os.system(
-            'tfkit-eval --model ./cache/10.pt --valid ../demo_data/generate.csv --metric classification --print')
+            'tfkit-eval --tag generate_0 --model ./cache/10.pt --valid ../demo_data/generate.csv --metric emf1 --print --beamsearch --outfile --tag onebyone_1')
+        self.assertTrue(result != 0)
+        result = os.system(
+            'tfkit-eval --tag onebyone_1 --model ./cache/10.pt --valid ../demo_data/generate.csv --metric emf1 --print --beamsearch --outfile  --tag onebyone_1')
         self.assertTrue(result == 0)
         result = os.system(
-            'tfkit-eval --model ./cache/10.pt --valid ../demo_data/generate.csv --metric emf1 --print --beamsearch --outfile')
+            'tfkit-eval --tag onebyone_1 --model ./cache/10.pt --valid ../demo_data/classification.csv --metric classification --print  --outfile  --tag onebyone_1')
+        self.assertTrue(result == 0)
+
+    def testEvalOnGen(self):
+        result = os.system(
+            'tfkit-eval --model ./cache/10.pt --valid ../demo_data/generate.csv --metric classification --print  --tag onebyone_1')
+        self.assertTrue(result == 0)
+        result = os.system(
+            'tfkit-eval --model ./cache/10.pt --valid ../demo_data/generate.csv --metric emf1 --print --beamsearch --outfile  --tag onebyone_1')
         self.assertTrue(result == 0)
 
     def testEvalClassify(self):
         result = os.system(
-            'tfkit-eval --model ./cache/10.pt --valid ../demo_data/classification.csv --metric classification --print  --outfile')
+            'tfkit-eval --model ./cache/10.pt --tag classify_0 --valid ../demo_data/classification.csv --metric classification  --print  --outfile')
         self.assertTrue(result == 0)
 
     def testEvalQA(self):
