@@ -38,11 +38,15 @@ def _f1_score(prediction, ground_truth):
 
 class EvalMetric:
 
-    def __init__(self, max_candidate=6):
+    def __init__(self, tokenizer, max_candidate=6):
         self.tasks = defaultdict(lambda: defaultdict(list))
         self.max_candidate = max_candidate
+        self.tokenizer = tokenizer
         self.target_list = defaultdict(lambda: defaultdict(int))
 
+    def tokenize_text(self, text):
+        return self.tokenizer.convert_tokens_to_string(self.tokenizer.tokenize(text))
+
     def add_record(self, input, predicted, target, task='default'):
         input = input.strip()
         if isinstance(target, str):
@@ -63,12 +67,12 @@ class EvalMetric:
             self.target_list[task][t] += 1
 
         self.tasks[task]['input'].append(input)
-        self.tasks[task]['predicted'].append(predicted)
+        self.tasks[task]['predicted'].append(self.tokenize_text(predicted))
         self.tasks[task]['predicteds'].append([predicted])
-        self.tasks[task]['predicted_list'].append(predicted.split(" ") if " " in predicted else list(predicted))
-        self.tasks[task]['target'].append(target)
+        self.tasks[task]['predicted_list'].append(predicted.split(" ") if " " in predicted else [predicted])
+        self.tasks[task]['target'].append(self.tokenize_text(target))
         self.tasks[task]['targets'].append(targets)
-        self.tasks[task]['target_list'].append(target.split(" ") if " " in target else list(target))
+        self.tasks[task]['target_list'].append(target.split(" ") if " " in target else [target])
 
     def get_record(self, task='default'):
         return self.tasks[task]
@@ -108,8 +112,8 @@ class EvalMetric:
             if "classification" in metric:
                 from sklearn.metrics import classification_report
                 from sklearn.preprocessing import MultiLabelBinarizer
-                mlb = MultiLabelBinarizer().fit(
-                    [t.split(" ") if " " in t else list(t) for t in self.target_list[task_name].keys()])
+                target_key = [t.split(" ") if " " in t else [t] for t in self.target_list[task_name].keys()]
+                mlb = MultiLabelBinarizer().fit([k for k in target_key if len(k) > 0])
                 result = classification_report(
                     mlb.transform(task['target_list']),
                     mlb.transform(task['predicted_list']),
